# Wasserstein
![alt-text](https://travis-ci.org/pkomiske/Wasserstein.svg?branch=master "Travis-CI Build Status")
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pkomiske/Wasserstein/master)

Python/C++ library for computing Wasserstein distances efficiently. See the [documentation](https://pkomiske.github.io/Wasserstein/).
